==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/imageviewer/kipiplugin_imageviewer.desktop.cmake <==
[Desktop Entry]
Name=Imageviewer
Name[ast]=Imageviewer
Name[bg]=Преглед на изображения
Name[ca]=Visor d'imatges
Name[ca@valencia]=Imageviewer
Name[cs]=Prohlížeč obrázků
Name[da]=Imageviewer
Name[de]=Bildbetrachter
Name[el]=Προβολέας εικόνας
Name[en_GB]=Imageviewer
Name[es]=Visor de imágenes
Name[et]=Pildinäitaja
Name[eu]=Irudi-ikustailea
Name[fr]=Imageviewer
Name[ga]=Amharcán Íomhánna
Name[gl]=Imageviewer
Name[he]=מציג התמונות
Name[hne]=फोटू-देखइया
Name[hu]=Képmegjelenítő
Name[is]=Myndaskoðari
Name[it]=Visore di immagini
Name[ja]=Imageviewer
Name[km]=កម្មវិធី​មើល​រូបភាព
Name[lv]=Attēlu skatītājs
Name[nb]=Bildeframviser
Name[nds]=Bildkieker
Name[nl]=Afbeeldingenviewer
Name[pa]=ਚਿੱਤਰ ਦਰਸ਼ਕ
Name[pl]=Przeglądarka obrazów
Name[pt]=Visualizador de Imagens
Name[pt_BR]=Visualizador de imagens
Name[ro]=Vizualizator de imagini
Name[ru]=Программа просмотра изображений
Name[sk]=Prezerač obrázkov
Name[sl]=Imageviewer
Name[sq]=Shfaqës Imazhesh
Name[sv]=Bildvisning
Name[th]=เครื่องมือแสดงภาพ
Name[tr]=Resim Gösterici
Name[uk]=Переглядач зображень
Name[x-test]=xxImageviewerxx
Name[zh_CN]=图像查看器
Name[zh_TW]=影像檢視器
Comment=A tool to preview images using OpenGL
Comment[ast]=Una ferramienta pa previsualizar imáxenes usando OpenGL
Comment[bg]=Инструмент за преглед на изображения с OpenGL
Comment[ca]=Una eina per a previsualitzar imatges utilitzant l'OpenGL
Comment[ca@valencia]=Una eina per a previsualitzar imatges utilitzant l'OpenGL
Comment[cs]=Nástroj na prohlížení obrázků pomocí OpenGL
Comment[da]=Et værktøj til at forhåndsvise med OpenGL
Comment[de]=Ein Werkzeug, um Vorschaubilder mittels OpenGL zu betrachten.
Comment[el]=Εργαλείο προεπισκόπησης εικόνων με χρήση του OpenGL
Comment[en_GB]=A tool to preview images using OpenGL
Comment[es]=Una herramienta para visualizar imágenes usando OpenGL
Comment[et]=Tööriist piltide eelvaatluseks OpenGL abil
Comment[eu]=OpenGL erabiliz irudiak aurreikusteko tresna bat 
Comment[fr]=Outil d'aperçu des images utilisant OpenGL
Comment[gl]=Unha ferramenta para previsualizar imaxes empregando OpenGL
Comment[he]=כלי לתצוגה מוקדמת של תמונות המשתמש ב-OpenGL
Comment[hne]=ओपनजीएल के उपयोग कर के फोटू प्रीव्यू देखाय के एक औजार
Comment[hu]=Egy eszköz képek előnézetéhez OpenGL használatával
Comment[is]=Verkfæri til að skoða myndir með OpenGL
Comment[it]=Uno strumento per vedere anteprime delle immagini con OpenGL
Comment[ja]=OpenGL を使って画像をプレビューするツール
Comment[km]=ឧបករណ៍​ដើម្បី​មើល​រូបភាព​ជា​មុន​ដោយ​ប្រើ OpenGL
Comment[lv]=Rīks attēlu priekšskatīšanai, izmantojot OpenGL
Comment[nb]=Et verktøy for å forhåndsvise bilder med OpenGL
Comment[nds]=En Warktüüch, mit dat sik Biller över OpenGL vörankieken laat
Comment[nl]=Een hulpmiddel om afbeeldingen met OpenGL te laten zien
Comment[pa]=OpenGL ਦੀ ਵਰਤੋਂ ਕਰਕੇ ਚਿੱਤਰਾਂ ਦੀ ਝਲਕ ਵੇਖਣ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do poglądu obrazów przy wykorzystaniu OpenGL
Comment[pt]=Uma ferramenta de antevisão de imagens que usa o OpenGL
Comment[pt_BR]=Uma ferramenta para visualizar imagens usando o OpenGL
Comment[ro]=O unealtă de previzualizat imagini utilizînd OpenGL
Comment[ru]=Инструмент для просмотра изображений на основе OpenGL
Comment[sk]=Nástroj na náhľad obrázkov s využitím OpenGL
Comment[sl]=Orodje za predogled slik z uporabo OpenGL
Comment[sq]=Një mjet për parjen e imazheve duke përdorur OpenGl
Comment[sv]=Ett verktyg för att förhandsgranska bilder med OpenGL
Comment[th]=เครื่องมือในการแสดงภาพตัวอย่างโดยใช้ OpenGL
Comment[tr]=OpenGL kullanarak resimleri ön izlemek için bir araç
Comment[uk]=Інструмент для перегляду зображень за допомогою OpenGL
Comment[x-test]=xxA tool to preview images using OpenGLxx
Comment[zh_CN]=一个使用 OpenGL 预览图像的工具
Comment[zh_TW]=使用 OpenGL 的影像預覽工具
Type=Service
Icon=ogl
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_imageviewer
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Markus Leuthold

==> digikam-3.1.0.tar.bz2: digikam-3.1.0/extra/kipi-plugins/imageviewer/kipiplugin_imageviewer.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Imageviewer
Name=Imageviewer
Name[ast]=Imageviewer
Name[bg]=Преглед на изображения
Name[bs]=Prikazivač slika
Name[ca]=Visor d'imatges
Name[ca@valencia]=Visor d'imatges
Name[cs]=Prohlížeč obrázků
Name[da]=Imageviewer
Name[de]=Bildbetrachter
Name[el]=Προβολέας εικόνας
Name[en_GB]=Imageviewer
Name[es]=Visor de imágenes
Name[et]=Pildinäitaja
Name[eu]=Irudi-ikustailea
Name[fr]=Imageviewer
Name[ga]=Amharcán Íomhánna
Name[gl]=Imageviewer
Name[he]=מציג התמונות
Name[hne]=फोटू-देखइया
Name[hu]=Képmegjelenítő
Name[is]=Myndaskoðari
Name[it]=Visore di immagini
Name[ja]=Imageviewer
Name[km]=កម្មវិធី​មើល​រូបភាព
Name[lv]=Attēlu skatītājs
Name[nb]=Bildeframviser
Name[nds]=Bildkieker
Name[nl]=Afbeeldingenviewer
Name[pa]=ਚਿੱਤਰ ਦਰਸ਼ਕ
Name[pl]=Przeglądarka obrazów
Name[pt]=Visualizador de Imagens
Name[pt_BR]=Visualizador de imagens
Name[ro]=Vizualizator de imagini
Name[ru]=Программа просмотра изображений
Name[sk]=Prezerač obrázkov
Name[sl]=Imageviewer
Name[sq]=Shfaqës Imazhesh
Name[sv]=Bildvisning
Name[th]=เครื่องมือแสดงภาพ
Name[tr]=Resim Gösterici
Name[uk]=Переглядач зображень
Name[x-test]=xxImageviewerxx
Name[zh_CN]=图像查看器
Name[zh_TW]=影像檢視器
Comment=A tool to preview images using OpenGL
Comment[ast]=Una ferramienta pa previsualizar imáxenes usando OpenGL
Comment[bg]=Инструмент за преглед на изображения с OpenGL
Comment[bs]=Alat za prikaz slika koristeći OpenGL
Comment[ca]=Una eina per a previsualitzar imatges utilitzant l'OpenGL
Comment[ca@valencia]=Una eina per a previsualitzar imatges utilitzant l'OpenGL
Comment[cs]=Nástroj na prohlížení obrázků pomocí OpenGL
Comment[da]=Et værktøj til at forhåndsvise med OpenGL
Comment[de]=Ein Werkzeug, um Vorschaubilder mittels OpenGL zu betrachten.
Comment[el]=Εργαλείο προεπισκόπησης εικόνων με χρήση του OpenGL
Comment[en_GB]=A tool to preview images using OpenGL
Comment[es]=Una herramienta para visualizar imágenes usando OpenGL
Comment[et]=Tööriist piltide eelvaatluseks OpenGL abil
Comment[eu]=OpenGL erabiliz irudiak aurreikusteko tresna bat 
Comment[fr]=Outil d'aperçu des images utilisant OpenGL
Comment[gl]=Unha ferramenta para previsualizar imaxes empregando OpenGL
Comment[he]=כלי לתצוגה מוקדמת של תמונות המשתמש ב-OpenGL
Comment[hne]=ओपनजीएल के उपयोग कर के फोटू प्रीव्यू देखाय के एक औजार
Comment[hu]=Egy eszköz képek előnézetéhez OpenGL használatával
Comment[is]=Verkfæri til að skoða myndir með OpenGL
Comment[it]=Uno strumento per vedere anteprime delle immagini con OpenGL
Comment[ja]=OpenGL を使って画像をプレビューするツール
Comment[km]=ឧបករណ៍​ដើម្បី​មើល​រូបភាព​ជា​មុន​ដោយ​ប្រើ OpenGL
Comment[lv]=Rīks attēlu priekšskatīšanai, izmantojot OpenGL
Comment[nb]=Et verktøy for å forhåndsvise bilder med OpenGL
Comment[nds]=En Warktüüch, mit dat sik Biller över OpenGL vörankieken laat
Comment[nl]=Een hulpmiddel om afbeeldingen met OpenGL te laten zien
Comment[pa]=OpenGL ਦੀ ਵਰਤੋਂ ਕਰਕੇ ਚਿੱਤਰਾਂ ਦੀ ਝਲਕ ਵੇਖਣ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do poglądu obrazów przy wykorzystaniu OpenGL
Comment[pt]=Uma ferramenta de antevisão de imagens que usa o OpenGL
Comment[pt_BR]=Uma ferramenta para visualizar imagens usando o OpenGL
Comment[ro]=O unealtă de previzualizat imagini utilizînd OpenGL
Comment[ru]=Инструмент для просмотра изображений на основе OpenGL
Comment[sk]=Nástroj na náhľad obrázkov s využitím OpenGL
Comment[sl]=Orodje za predogled slik z uporabo OpenGL
Comment[sq]=Një mjet për parjen e imazheve duke përdorur OpenGl
Comment[sv]=Ett verktyg för att förhandsgranska bilder med OpenGL
Comment[th]=เครื่องมือในการแสดงภาพตัวอย่างโดยใช้ OpenGL
Comment[tr]=OpenGL kullanarak resimleri ön izlemek için bir araç
Comment[uk]=Інструмент для перегляду зображень за допомогою OpenGL
Comment[x-test]=xxA tool to preview images using OpenGLxx
Comment[zh_CN]=一个使用 OpenGL 预览图像的工具
Comment[zh_TW]=使用 OpenGL 的影像預覽工具
Type=Service
Icon=ogl
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_imageviewer
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Markus Leuthold
